.. _examples:
==================
Examples
==================

Welcome to the ``pyXMIP`` example page!

On this page, there are a variety of Jupyter notebooks and other example materials with coverage of most of the
material from this library.

.. card-carousel:: 1

    .. card:: pyXMIP Overview Cookbook
        :link: examples/Introduction
        :link-type: doc

        A quick and dirty guide to get your feet wet with.

        +++

        |beginner| |30min|




.. |beginner| image:: https://img.shields.io/badge/Difficulty-Beginner-green
.. |intermediate| image:: https://img.shields.io/badge/Difficulty-Intermediate-blue
.. |advanced| image:: https://img.shields.io/badge/Difficulty-Advanced-black
.. |10min| image:: https://img.shields.io/badge/10min-blue
.. |5min| image:: https://img.shields.io/badge/5min-blue
.. |20min| image:: https://img.shields.io/badge/20min-blue
.. |30min| image:: https://img.shields.io/badge/30min-blue
.. |40min| image:: https://img.shields.io/badge/40min-blue
.. |60min| image:: https://img.shields.io/badge/60min-blue
.. |feature| image:: https://img.shields.io/badge/Feature-purple
.. |nyi| image::  https://img.shields.io/badge/NotYetImplemented-red
